"""VRS application."""
from fastapi import FastAPI

from contextlib import asynccontextmanager
import logging.config
from pathlib import Path

import backend.models
from backend.core.database import create_tables, async_session
from backend.core.database import create_tables
from backend.api.api_v1.api import api_router
from backend.exception import register_exception_handlers

from backend.core.config import settings

logging.config.fileConfig(Path(__file__).with_name("logging.conf"), disable_existing_loggers=False)

logger = logging.getLogger(__name__)

async def shutdown():
    logger.debug("bye") 

@asynccontextmanager
async def database_lifespan(app: FastAPI):
    logger.debug("create_tables")
    await create_tables()
    yield
    # await close_database()

@asynccontextmanager
async def lifespan(app: FastAPI):

    async with (
        database_lifespan(app),
    ):
        yield 
    await shutdown()

app = FastAPI(title=settings.title,
            description=settings.description,
            openapi_url=f"/openapi.json",
            lifespan=lifespan)

app.include_router(api_router, prefix=settings.api_url)
register_exception_handlers(app)