from backend.core.config import settings

from sqlalchemy.ext.asyncio import AsyncAttrs, async_sessionmaker, create_async_engine, AsyncSession
from sqlalchemy.orm import DeclarativeBase
from sqlalchemy import types as sa_types
import datetime

async_engine = create_async_engine(
    str(settings.database_url), echo=False, future=True,
    pool_pre_ping=True)

async_session = async_sessionmaker(
    autocommit=False,
    autoflush=False,
    expire_on_commit=False,
    class_=AsyncSession,
    bind=async_engine,
)

class Base(DeclarativeBase, AsyncAttrs):
    """Base class for models."""

    type_annotation_map = {
        # always require timezones for datetime objects
        datetime.datetime: sa_types.DateTime(timezone=True),
    }

async def create_tables():
    async with async_engine.begin() as conn:
        # Create all tables defined by Base
        await conn.run_sync(Base.metadata.create_all)

__all__ = ['async_session', 'create_tables', 'Base']