from fastapi import FastAPI, HTTPException, Request
import backend.exceptions as exceptions
from starlette import status

from sqlalchemy.exc import IntegrityError

def register_exception_handlers(app: FastAPI):
  @app.exception_handler(IntegrityError)
  def integrity_error_handler(_request: Request, e: IntegrityError):
    if "UNIQUE constraint failed" in str(e):
      raise HTTPException(status_code=status.HTTP_409_CONFLICT, detail="Value already exists")
    else:
      raise HTTPException(status_code=status.HTTP_400_BAD_REQUEST, detail=f"{e}")
    
  @app.exception_handler(exceptions.BackendNotFoundException)
  def backend_exception_handler(_request: Request, e: exceptions.BackendNotFoundException):
    raise HTTPException(status_code=status.HTTP_404_NOT_FOUND, detail=f"{e}")

  @app.exception_handler(exceptions.BackendException)
  def backend_exception_handler(_request: Request, e: exceptions.BackendException):
    raise HTTPException(status_code=status.HTTP_400_BAD_REQUEST, detail=f"{e}")

  @app.exception_handler(exceptions.BackendTooEarlyException)
  def backend_not_ready_exception_handler(_request: Request, e: exceptions.BackendTooEarlyException):
    raise HTTPException(status_code=status.HTTP_425_TOO_EARLY, detail=f"{e}")

  @app.exception_handler(exceptions.BackendGoneException)
  def backend_gone_exception_handler(_request: Request, e: exceptions.BackendGoneException):
    raise HTTPException(status_code=status.HTTP_410_GONE, detail=f"{e}")