from .deps import *

from enum import Enum

from sqlalchemy.orm import Mapped, mapped_column
from sqlalchemy import Enum as SQLEnum
import datetime
import uuid

class ClusterStatus(Enum):
    SUBMITTED = "submitted"
    ACTIVE = "active"
    FINISHED = "finished"
    FAILED = "failed"

class Cluster(Base):
    __tablename__ = 'clusters'  # This will be the name of the table

    id: Mapped[str] = mapped_column(String(36), primary_key=True, default=lambda: str(uuid.uuid4()))
    name: Mapped[str] = mapped_column(String, nullable=False)
    status: Mapped[ClusterStatus] = mapped_column(SQLEnum(ClusterStatus), default=ClusterStatus.SUBMITTED, nullable=False)
    creation_time = Column(DateTime, nullable=False, default=datetime.datetime.now(datetime.timezone.utc))  # Auto-filled with UTC time

    def __repr__(self):
        return f"<Cluster(id={self.id}, name={self.name}, creation_time={self.creation_time})>"