# from .flavor import FlavorSchema
from .volume import VolumeSchema
from pydantic import BaseModel, Field
from typing import List

import uuid

from typing import List, Optional, Union

class VmNetworkSchema(BaseModel):
    network_name: str = Field(..., description="The name of the network interface.")
    multus_ip: str = Field(..., description="The IP address assigned to the Multus interface.")
    gateway: str = Field(..., description="The gateway IP for the network.")
    bridge_name: Optional[str] = Field("br0", description="The bridge name, default is 'br0'. Optional field.")

class PublicVmSchema(BaseModel):
    vmi_name: str = Field(..., description="Name of the VirtualMachineInstance.")
    disk_size: Union[int, str] = Field(20, description="Disk size in Gi (default: 20).")
    labeling_enabled: bool = Field(False, description="Whether to add a label/nodeSelector (default: False).")
    label: str = Field("slices-gr", description="The label key (default: 'slices-gr').")
    multus_interfaces: Optional[List[VmNetworkSchema]] = Field(..., description="A list of Multus configuration dictionaries.")
    roles: List[str] = Field(..., description="A list of roles, e.g. ['control plane', 'worker'] or ['worker'].")
    flavor: str = Field(..., description="Name of the flavor to use for the VM")

class VmSchema(PublicVmSchema):
    # vmi_name: str = Field(..., description="Name of the VirtualMachineInstance.")
    # disk_size: Union[int, str] = Field(20, description="Disk size in Gi (default: 20).")
    # disk_image: str = Field(..., description="URL of the disk image.")
    cpu_cores: int = Field(2, description="Number of CPU cores (default: 2).")
    ram: str = Field("2048M", description="Amount of RAM (default: '2048M').")
    # labeling_enabled: bool = Field(False, description="Whether to add a label/nodeSelector (default: False).")
    # label: str = Field("slices-gr", description="The label key (default: 'slices-gr').")
    # multus_interfaces: Optional[List[VmNetworkSchema]] = Field(..., description="A list of Multus configuration dictionaries.")
    # roles: List[str] = Field(..., description="A list of roles, e.g. ['control plane', 'worker'] or ['worker'].")