
from backend.core.database import async_session
import backend.engines.cluster as engine
import backend.exceptions as exceptions
import backend.schemas as schemas
import backend.models as models
from backend.core.taskiq import broker

from taskiq import Context, TaskiqDepends
from typing import Annotated
from sqlalchemy import update

import logging
logger = logging.getLogger(__name__)

def get_task_id(context: Annotated[Context, TaskiqDepends()]) -> str:
    return context.message.task_id

@broker.task()
async def create_cluster(
    cluster_info: schemas.ClusterSchema,
    task_id: str = TaskiqDepends(get_task_id)
) -> int:
    # Create the cluster
    status = models.cluster.ClusterStatus.FAILED
    try:
        await engine.create_cluster(cluster=cluster_info)
        status = models.cluster.ClusterStatus.ACTIVE
    # ... failed to create it
    except exceptions.BackendException:
        status = models.cluster.ClusterStatus.FAILED
    # ... commmit new state
    finally:
        db = async_session()
        await db.execute(
            update(models.Cluster).where(models.Cluster.id == cluster_info.id).values(status=status)
        )
        await db.commit()